## xamcheck-utils

Utility functions used in python projects of [Xamcheck](http://xamcheck.com).

[![Build Status](https://travis-ci.org/psjinx/xamcheck-utils.svg?branch=master)](https://travis-ci.org/psjinx/xamcheck-utils)
